import { Resource, ResourceProps } from 'aws-cdk-lib';
import { IConstruct } from 'constructs';
import { IIpamPool, Ipam } from '../ec2';
import { ICidrProvider } from '../ec2/lib/ip-addresses/network-provider';
import { ResourceShare } from '../ram';
export interface IpAddressManagerSharingProps {
    readonly allowExternalPricipals?: boolean;
    readonly enabled?: boolean;
}
export interface IpAddressManagerProps extends ResourceProps {
    readonly vpcAllocationMask?: number;
    readonly vpcPoolCidrs?: string[];
    readonly vpcRegionMask?: number;
    readonly regions?: string[];
    readonly sharing?: IpAddressManagerSharingProps;
}
export interface AddPoolOptions {
    readonly cidrs?: string[];
    readonly defaultNetmaskLength?: number;
}
export interface AllocatePrivateNetworkOptions {
    readonly netmask?: number;
    readonly pool?: string;
}
export interface GetVpcConfigurationOptions {
    readonly netmask?: number;
}
export declare class IpAddressManager extends Resource {
    static readonly DEFAULT_VPC_ALLOCATION_MASK: number;
    static readonly DEFAULT_VPC_POOL_CIDRS: string[];
    static readonly DEFAULT_VPC_REGION_MASK: number;
    private readonly privateVpcPool;
    readonly allowExternalPricipals: boolean;
    readonly sharingEnabled: boolean;
    readonly vpcAllocationMask: number;
    readonly ipam: Ipam;
    get resourceShare(): ResourceShare | undefined;
    constructor(scope: IConstruct, id: string, props?: IpAddressManagerProps);
    addRegion(region: string): void;
    protected privateVpcPoolForRegion(region: string): IIpamPool;
    protected privateVpcPoolForEnvironment(account: string, region: string): IIpamPool;
    getVpcConfiguration(scope: IConstruct, id: string, options?: GetVpcConfigurationOptions): ICidrProvider;
    protected registerAccount(account: string, pool: IIpamPool): void;
    registerCidr(scope: IConstruct, id: string, cidr: string): void;
}
