import { Resource, ResourceProps } from 'aws-cdk-lib';
import { IBucket } from 'aws-cdk-lib/aws-s3';
import { IConstruct } from 'constructs';
import { FourTierNetworkHub, IpAddressManager } from '.';
import { FourTierNetworkSpoke } from './four-tier-network-spoke';
import { FlowLogFormat } from '../ec2';
import { GlobalNetwork } from '../networkmanager/global-network';
export interface NetworkControllerProps extends ResourceProps {
    readonly defaultNetmask?: number;
    readonly flowLogBucket?: IBucket;
    readonly flowLogFormat?: FlowLogFormat;
}
export interface AddNetworkOptions {
    readonly availabilityZones?: string[];
    readonly maxAzs?: number;
    readonly netmask?: number;
}
export declare class NetworkController extends Resource {
    private readonly _hubs;
    private readonly _registeredAccounts;
    private readonly _registeredRegions;
    readonly defaultNetmask: number;
    readonly flowLogFormat: FlowLogFormat;
    readonly addressManager: IpAddressManager;
    readonly flowLogBucket: IBucket;
    readonly globalNetwork: GlobalNetwork;
    get registeredAccounts(): string[];
    get registeredRegions(): string[];
    constructor(scope: IConstruct, id: string, props?: NetworkControllerProps);
    addHub(scope: IConstruct, id: string, options?: AddNetworkOptions): FourTierNetworkHub;
    addSpoke(scope: IConstruct, id: string, options?: AddNetworkOptions): FourTierNetworkSpoke;
    registerCidr(scope: IConstruct, id: string, cidr: string): void;
    protected registerAccount(account: string): void;
    protected registerRegion(region: string): void;
}
